==> kvision-bootstrap-typeahead-remote-5.15.1.jar: kvision-kvision-bootstrap-typeahead-remote-js-legacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin', 'kvision-js-legacy', 'kvision-kvision-bootstrap-typeahead-js-legacy', 'kvision-kvision-common-remote-js-legacy', 'kotlinx-serialization-kotlinx-serialization-core-js-legacy'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'), require('kvision-js-legacy'), require('kvision-kvision-bootstrap-typeahead-js-legacy'), require('kvision-kvision-common-remote-js-legacy'), require('kotlinx-serialization-kotlinx-serialization-core-js-legacy'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-typeahead-remote-js-legacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'kvision-kvision-bootstrap-typeahead-remote-js-legacy'.");
    }
    if (typeof this['kvision-js-legacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-typeahead-remote-js-legacy'. Its dependency 'kvision-js-legacy' was not found. Please, check whether 'kvision-js-legacy' is loaded prior to 'kvision-kvision-bootstrap-typeahead-remote-js-legacy'.");
    }
    if (typeof this['kvision-kvision-bootstrap-typeahead-js-legacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-typeahead-remote-js-legacy'. Its dependency 'kvision-kvision-bootstrap-typeahead-js-legacy' was not found. Please, check whether 'kvision-kvision-bootstrap-typeahead-js-legacy' is loaded prior to 'kvision-kvision-bootstrap-typeahead-remote-js-legacy'.");
    }
    if (typeof this['kvision-kvision-common-remote-js-legacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-typeahead-remote-js-legacy'. Its dependency 'kvision-kvision-common-remote-js-legacy' was not found. Please, check whether 'kvision-kvision-common-remote-js-legacy' is loaded prior to 'kvision-kvision-bootstrap-typeahead-remote-js-legacy'.");
    }
    if (typeof this['kotlinx-serialization-kotlinx-serialization-core-js-legacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-typeahead-remote-js-legacy'. Its dependency 'kotlinx-serialization-kotlinx-serialization-core-js-legacy' was not found. Please, check whether 'kotlinx-serialization-kotlinx-serialization-core-js-legacy' is loaded prior to 'kvision-kvision-bootstrap-typeahead-remote-js-legacy'.");
    }
    root['kvision-kvision-bootstrap-typeahead-remote-js-legacy'] = factory(typeof this['kvision-kvision-bootstrap-typeahead-remote-js-legacy'] === 'undefined' ? {} : this['kvision-kvision-bootstrap-typeahead-remote-js-legacy'], kotlin, this['kvision-js-legacy'], this['kvision-kvision-bootstrap-typeahead-js-legacy'], this['kvision-kvision-common-remote-js-legacy'], this['kotlinx-serialization-kotlinx-serialization-core-js-legacy']);
  }
}(this, function (_, Kotlin, $module$kvision_js_legacy, $module$kvision_kvision_bootstrap_typeahead_js_legacy, $module$kvision_kvision_common_remote_js_legacy, $module$kotlinx_serialization_kotlinx_serialization_core_js_legacy) {
  'use strict';
  var $$importsForInline$$ = _.$$importsForInline$$ || (_.$$importsForInline$$ = {});
  var InputType = $module$kvision_js_legacy.io.kvision.html.InputType;
  var AbstractText = $module$kvision_js_legacy.io.kvision.form.text.AbstractText;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var TypeaheadInput = $module$kvision_kvision_bootstrap_typeahead_js_legacy.io.kvision.form.text.TypeaheadInput;
  var TaAjaxOptions = $module$kvision_kvision_bootstrap_typeahead_js_legacy.io.kvision.form.text.TaAjaxOptions;
  var drop = Kotlin.kotlin.text.drop_6ic1pp$;
  var utils = $module$kvision_js_legacy.io.kvision.utils;
  var listOf = Kotlin.kotlin.collections.listOf_i5x0yv$;
  var JsonRpcRequest = $module$kvision_kvision_common_remote_js_legacy.io.kvision.remote.JsonRpcRequest;
  var getKClass = Kotlin.getKClass;
  var createKType = Kotlin.createKType;
  var kotlin_js_internal_StringCompanionObject = Kotlin.kotlin.js.internal.StringCompanionObject;
  var serializer = $module$kotlinx_serialization_kotlinx_serialization_core_js_legacy.kotlinx.serialization.builtins.serializer_6eet4j$;
  var ListSerializer = $module$kotlinx_serialization_kotlinx_serialization_core_js_legacy.kotlinx.serialization.builtins.ListSerializer_swdriu$;
  var HttpType$valueOf = $module$kvision_kvision_bootstrap_typeahead_js_legacy.io.kvision.form.text.HttpType.valueOf_61zpoe$;
  var serializer_0 = $module$kotlinx_serialization_kotlinx_serialization_core_js_legacy.kotlinx.serialization.serializer_ca95z9$;
  var KSerializer = $module$kotlinx_serialization_kotlinx_serialization_core_js_legacy.kotlinx.serialization.KSerializer;
  var throwCCE = Kotlin.throwCCE;
  var copyToArray = Kotlin.kotlin.collections.copyToArray;
  TypeaheadRemote.prototype = Object.create(AbstractText.prototype);
  TypeaheadRemote.prototype.constructor = TypeaheadRemote;
  TypeaheadRemoteInput.prototype = Object.create(TypeaheadInput.prototype);
  TypeaheadRemoteInput.prototype.constructor = TypeaheadRemoteInput;
  function TypeaheadRemote(serviceManager, function_0, stateFunction, items, minLength, delay, type, value, name, label, rich, floating, init) {
    if (stateFunction === void 0)
      stateFunction = null;
    if (items === void 0)
      items = 8;
    if (minLength === void 0)
      minLength = 1;
    if (delay === void 0)
      delay = 0;
    if (type === void 0)
      type = InputType.TEXT;
    if (value === void 0)
      value = null;
    if (name === void 0)
      name = null;
    if (label === void 0)
      label = null;
    if (rich === void 0)
      rich = false;
    if (floating === void 0)
      floating = false;
    if (init === void 0)
      init = null;
    AbstractText.call(this, label, rich, floating);
    this.stateFunction_xn32t0$_0 = stateFunction;
    var $receiver = new TypeaheadRemoteInput(serviceManager, function_0, this.stateFunction_xn32t0$_0, items, minLength, delay, type, value);
    var closure$name = name;
    $receiver.id = this.idc;
    $receiver.name = closure$name;
    this.input_rigeej$_0 = $receiver;
    this.input.eventTarget = this;
    if (!floating) {
      this.addPrivate_87eobz$(this.flabel);
      this.addPrivate_87eobz$(this.input);
    } else {
      this.addPrivate_87eobz$(this.input);
      this.addPrivate_87eobz$(this.flabel);
    }
    this.addPrivate_87eobz$(this.invalidFeedback);
    init != null ? init(this) : null;
    this.floatingPlaceholder();
  }
  Object.defineProperty(TypeaheadRemote.prototype, 'items', {
    configurable: true,
    get: function () {
      return this.input.items;
    },
    set: function (value) {
      this.input.items = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'minLength', {
    configurable: true,
    get: function () {
      return this.input.minLength;
    },
    set: function (value) {
      this.input.minLength = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'showHintOnFocus', {
    configurable: true,
    get: function () {
      return this.input.showHintOnFocus;
    },
    set: function (value) {
      this.input.showHintOnFocus = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'autoSelect', {
    configurable: true,
    get: function () {
      return this.input.autoSelect;
    },
    set: function (value) {
      this.input.autoSelect = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'delay', {
    configurable: true,
    get: function () {
      return this.input.taAjaxOptions;
    },
    set: function (value) {
      this.input.taAjaxOptions = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'fitToElement', {
    configurable: true,
    get: function () {
      return this.input.fitToElement;
    },
    set: function (value) {
      this.input.fitToElement = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'type', {
    configurable: true,
    get: function () {
      return this.input.type;
    },
    set: function (value) {
      this.input.type = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'autocomplete', {
    configurable: true,
    get: function () {
      return this.input.autocomplete;
    },
    set: function (value) {
      this.input.autocomplete = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'input', {
    configurable: true,
    get: function () {
      return this.input_rigeej$_0;
    }
  });
  TypeaheadRemote.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'TypeaheadRemote',
    interfaces: [AbstractText]
  };
  function typeaheadRemote($receiver, serviceManager, function_0, stateFunction, items, minLength, delay, type, value, name, label, rich, floating, init) {
    if (stateFunction === void 0)
      stateFunction = null;
    if (items === void 0)
      items = 8;
    if (minLength === void 0)
      minLength = 1;
    if (delay === void 0)
      delay = 0;
    if (type === void 0)
      type = InputType.TEXT;
    if (value === void 0)
      value = null;
    if (name === void 0)
      name = null;
    if (label === void 0)
      label = null;
    if (rich === void 0)
      rich = false;
    if (floating === void 0)
      floating = false;
    if (init === void 0)
      init = null;
    var typeaheadRemote = new TypeaheadRemote(serviceManager, function_0, stateFunction, items, minLength, delay, type, value, name, label, rich, floating, init);
    $receiver.add_87eobz$(typeaheadRemote);
    return typeaheadRemote;
  }
  function TypeaheadRemoteInput(serviceManager, function_0, stateFunction, items, minLength, delay, type, value, taAjaxOptions, className, init) {
    if (stateFunction === void 0)
      stateFunction = null;
    if (items === void 0)
      items = 8;
    if (minLength === void 0)
      minLength = 1;
    if (delay === void 0)
      delay = 0;
    if (type === void 0)
      type = InputType.TEXT;
    if (value === void 0)
      value = null;
    if (taAjaxOptions === void 0)
      taAjaxOptions = null;
    if (className === void 0)
      className = null;
    if (init === void 0)
      init = null;
    TypeaheadInput.call(this, null, null, null, items, minLength, delay, type, value, className);
    this.stateFunction_7p3yg8$_0 = stateFunction;
    this.kvUrlPrefix_6kah5n$_0 = window['kv_remote_url_prefix'];
    this.urlPrefix_c4c7g0$_0 = this.kvUrlPrefix_6kah5n$_0 != undefined ? this.kvUrlPrefix_6kah5n$_0.toString() + '/' : '';
    var tmp$ = serviceManager.requireCall_lefff9$(function_0);
    var url = tmp$.component1()
    , method = tmp$.component2();
    var tempAjaxOptions = taAjaxOptions != null ? taAjaxOptions : new TaAjaxOptions();
    this.taAjaxOptions = tempAjaxOptions.copy_e0rzf$(this.urlPrefix_c4c7g0$_0 + drop(url, 1), TypeaheadRemoteInput_init$lambda(this, url), TypeaheadRemoteInput_init$lambda_0, void 0, HttpType$valueOf(method.name));
    init != null ? init(this) : null;
  }
  function TypeaheadRemoteInput_init$lambda(this$TypeaheadRemoteInput, closure$url) {
    return function (query) {
      var tmp$, tmp$_0;
      var squery = JSON.stringify(query);
      var state = (tmp$_0 = (tmp$ = this$TypeaheadRemoteInput.stateFunction_7p3yg8$_0) != null ? tmp$() : null) != null ? JSON.stringify(tmp$_0) : null;
      var $receiver = utils.Serialization.plain;
      var value = new JsonRpcRequest(0, closure$url, listOf([squery, state]));
      var tmp$_1;
      return $receiver.encodeToString_tf03ej$(Kotlin.isType(tmp$_1 = serializer_0($receiver.serializersModule, createKType(getKClass(JsonRpcRequest), [], false)), KSerializer) ? tmp$_1 : throwCCE(), value);
    };
  }
  function TypeaheadRemoteInput_init$lambda_0(it) {
    return copyToArray(utils.Serialization.plain.decodeFromString_awif5v$(ListSerializer(serializer(kotlin_js_internal_StringCompanionObject)), it.result));
  }
  TypeaheadRemoteInput.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'TypeaheadRemoteInput',
    interfaces: [TypeaheadInput]
  };
  function typeaheadRemoteInput($receiver, serviceManager, function_0, stateFunction, items, minLength, delay, type, value, taAjaxOptions, className, init) {
    if (stateFunction === void 0)
      stateFunction = null;
    if (items === void 0)
      items = 8;
    if (minLength === void 0)
      minLength = 1;
    if (delay === void 0)
      delay = 0;
    if (type === void 0)
      type = InputType.TEXT;
    if (value === void 0)
      value = null;
    if (taAjaxOptions === void 0)
      taAjaxOptions = null;
    if (className === void 0)
      className = null;
    if (init === void 0)
      init = null;
    var typeaheadRemoteInput = new TypeaheadRemoteInput(serviceManager, function_0, stateFunction, items, minLength, delay, type, value, taAjaxOptions, className, init);
    $receiver.add_87eobz$(typeaheadRemoteInput);
    return typeaheadRemoteInput;
  }
  var package$io = _.io || (_.io = {});
  var package$kvision = package$io.kvision || (package$io.kvision = {});
  var package$form = package$kvision.form || (package$kvision.form = {});
  var package$text = package$form.text || (package$form.text = {});
  package$text.TypeaheadRemote = TypeaheadRemote;
  package$text.typeaheadRemote_xzip1p$ = typeaheadRemote;
  $$importsForInline$$['kotlinx-serialization-kotlinx-serialization-core-js-legacy'] = $module$kotlinx_serialization_kotlinx_serialization_core_js_legacy;
  package$text.TypeaheadRemoteInput = TypeaheadRemoteInput;
  package$text.typeaheadRemoteInput_jzo5km$ = typeaheadRemoteInput;
  Kotlin.defineModule('kvision-kvision-bootstrap-typeahead-remote-js-legacy', _);
  return _;
}));

==> kvision-bootstrap-typeahead-remote-5.15.3.jar: kvision-kvision-bootstrap-typeahead-remote-js-legacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin', 'kvision-js-legacy', 'kvision-kvision-bootstrap-typeahead-js-legacy', 'kvision-kvision-common-remote-js-legacy', 'kotlinx-serialization-kotlinx-serialization-core-js-legacy'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'), require('kvision-js-legacy'), require('kvision-kvision-bootstrap-typeahead-js-legacy'), require('kvision-kvision-common-remote-js-legacy'), require('kotlinx-serialization-kotlinx-serialization-core-js-legacy'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-typeahead-remote-js-legacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'kvision-kvision-bootstrap-typeahead-remote-js-legacy'.");
    }
    if (typeof this['kvision-js-legacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-typeahead-remote-js-legacy'. Its dependency 'kvision-js-legacy' was not found. Please, check whether 'kvision-js-legacy' is loaded prior to 'kvision-kvision-bootstrap-typeahead-remote-js-legacy'.");
    }
    if (typeof this['kvision-kvision-bootstrap-typeahead-js-legacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-typeahead-remote-js-legacy'. Its dependency 'kvision-kvision-bootstrap-typeahead-js-legacy' was not found. Please, check whether 'kvision-kvision-bootstrap-typeahead-js-legacy' is loaded prior to 'kvision-kvision-bootstrap-typeahead-remote-js-legacy'.");
    }
    if (typeof this['kvision-kvision-common-remote-js-legacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-typeahead-remote-js-legacy'. Its dependency 'kvision-kvision-common-remote-js-legacy' was not found. Please, check whether 'kvision-kvision-common-remote-js-legacy' is loaded prior to 'kvision-kvision-bootstrap-typeahead-remote-js-legacy'.");
    }
    if (typeof this['kotlinx-serialization-kotlinx-serialization-core-js-legacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-typeahead-remote-js-legacy'. Its dependency 'kotlinx-serialization-kotlinx-serialization-core-js-legacy' was not found. Please, check whether 'kotlinx-serialization-kotlinx-serialization-core-js-legacy' is loaded prior to 'kvision-kvision-bootstrap-typeahead-remote-js-legacy'.");
    }
    root['kvision-kvision-bootstrap-typeahead-remote-js-legacy'] = factory(typeof this['kvision-kvision-bootstrap-typeahead-remote-js-legacy'] === 'undefined' ? {} : this['kvision-kvision-bootstrap-typeahead-remote-js-legacy'], kotlin, this['kvision-js-legacy'], this['kvision-kvision-bootstrap-typeahead-js-legacy'], this['kvision-kvision-common-remote-js-legacy'], this['kotlinx-serialization-kotlinx-serialization-core-js-legacy']);
  }
}(this, function (_, Kotlin, $module$kvision_js_legacy, $module$kvision_kvision_bootstrap_typeahead_js_legacy, $module$kvision_kvision_common_remote_js_legacy, $module$kotlinx_serialization_kotlinx_serialization_core_js_legacy) {
  'use strict';
  var $$importsForInline$$ = _.$$importsForInline$$ || (_.$$importsForInline$$ = {});
  var InputType = $module$kvision_js_legacy.io.kvision.html.InputType;
  var AbstractText = $module$kvision_js_legacy.io.kvision.form.text.AbstractText;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var TypeaheadInput = $module$kvision_kvision_bootstrap_typeahead_js_legacy.io.kvision.form.text.TypeaheadInput;
  var TaAjaxOptions = $module$kvision_kvision_bootstrap_typeahead_js_legacy.io.kvision.form.text.TaAjaxOptions;
  var drop = Kotlin.kotlin.text.drop_6ic1pp$;
  var utils = $module$kvision_js_legacy.io.kvision.utils;
  var listOf = Kotlin.kotlin.collections.listOf_i5x0yv$;
  var JsonRpcRequest = $module$kvision_kvision_common_remote_js_legacy.io.kvision.remote.JsonRpcRequest;
  var getKClass = Kotlin.getKClass;
  var createKType = Kotlin.createKType;
  var kotlin_js_internal_StringCompanionObject = Kotlin.kotlin.js.internal.StringCompanionObject;
  var serializer = $module$kotlinx_serialization_kotlinx_serialization_core_js_legacy.kotlinx.serialization.builtins.serializer_6eet4j$;
  var ListSerializer = $module$kotlinx_serialization_kotlinx_serialization_core_js_legacy.kotlinx.serialization.builtins.ListSerializer_swdriu$;
  var HttpType$valueOf = $module$kvision_kvision_bootstrap_typeahead_js_legacy.io.kvision.form.text.HttpType.valueOf_61zpoe$;
  var serializer_0 = $module$kotlinx_serialization_kotlinx_serialization_core_js_legacy.kotlinx.serialization.serializer_ca95z9$;
  var KSerializer = $module$kotlinx_serialization_kotlinx_serialization_core_js_legacy.kotlinx.serialization.KSerializer;
  var throwCCE = Kotlin.throwCCE;
  var copyToArray = Kotlin.kotlin.collections.copyToArray;
  TypeaheadRemote.prototype = Object.create(AbstractText.prototype);
  TypeaheadRemote.prototype.constructor = TypeaheadRemote;
  TypeaheadRemoteInput.prototype = Object.create(TypeaheadInput.prototype);
  TypeaheadRemoteInput.prototype.constructor = TypeaheadRemoteInput;
  function TypeaheadRemote(serviceManager, function_0, stateFunction, items, minLength, delay, type, value, name, label, rich, floating, init) {
    if (stateFunction === void 0)
      stateFunction = null;
    if (items === void 0)
      items = 8;
    if (minLength === void 0)
      minLength = 1;
    if (delay === void 0)
      delay = 0;
    if (type === void 0)
      type = InputType.TEXT;
    if (value === void 0)
      value = null;
    if (name === void 0)
      name = null;
    if (label === void 0)
      label = null;
    if (rich === void 0)
      rich = false;
    if (floating === void 0)
      floating = false;
    if (init === void 0)
      init = null;
    AbstractText.call(this, label, rich, floating);
    this.stateFunction_xn32t0$_0 = stateFunction;
    var $receiver = new TypeaheadRemoteInput(serviceManager, function_0, this.stateFunction_xn32t0$_0, items, minLength, delay, type, value);
    var closure$name = name;
    $receiver.id = this.idc;
    $receiver.name = closure$name;
    this.input_rigeej$_0 = $receiver;
    this.input.eventTarget = this;
    if (!floating) {
      this.addPrivate_87eobz$(this.flabel);
      this.addPrivate_87eobz$(this.input);
    } else {
      this.addPrivate_87eobz$(this.input);
      this.addPrivate_87eobz$(this.flabel);
    }
    this.addPrivate_87eobz$(this.invalidFeedback);
    init != null ? init(this) : null;
    this.floatingPlaceholder();
  }
  Object.defineProperty(TypeaheadRemote.prototype, 'items', {
    configurable: true,
    get: function () {
      return this.input.items;
    },
    set: function (value) {
      this.input.items = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'minLength', {
    configurable: true,
    get: function () {
      return this.input.minLength;
    },
    set: function (value) {
      this.input.minLength = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'showHintOnFocus', {
    configurable: true,
    get: function () {
      return this.input.showHintOnFocus;
    },
    set: function (value) {
      this.input.showHintOnFocus = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'autoSelect', {
    configurable: true,
    get: function () {
      return this.input.autoSelect;
    },
    set: function (value) {
      this.input.autoSelect = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'delay', {
    configurable: true,
    get: function () {
      return this.input.taAjaxOptions;
    },
    set: function (value) {
      this.input.taAjaxOptions = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'fitToElement', {
    configurable: true,
    get: function () {
      return this.input.fitToElement;
    },
    set: function (value) {
      this.input.fitToElement = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'type', {
    configurable: true,
    get: function () {
      return this.input.type;
    },
    set: function (value) {
      this.input.type = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'autocomplete', {
    configurable: true,
    get: function () {
      return this.input.autocomplete;
    },
    set: function (value) {
      this.input.autocomplete = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'input', {
    configurable: true,
    get: function () {
      return this.input_rigeej$_0;
    }
  });
  TypeaheadRemote.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'TypeaheadRemote',
    interfaces: [AbstractText]
  };
  function typeaheadRemote($receiver, serviceManager, function_0, stateFunction, items, minLength, delay, type, value, name, label, rich, floating, init) {
    if (stateFunction === void 0)
      stateFunction = null;
    if (items === void 0)
      items = 8;
    if (minLength === void 0)
      minLength = 1;
    if (delay === void 0)
      delay = 0;
    if (type === void 0)
      type = InputType.TEXT;
    if (value === void 0)
      value = null;
    if (name === void 0)
      name = null;
    if (label === void 0)
      label = null;
    if (rich === void 0)
      rich = false;
    if (floating === void 0)
      floating = false;
    if (init === void 0)
      init = null;
    var typeaheadRemote = new TypeaheadRemote(serviceManager, function_0, stateFunction, items, minLength, delay, type, value, name, label, rich, floating, init);
    $receiver.add_87eobz$(typeaheadRemote);
    return typeaheadRemote;
  }
  function TypeaheadRemoteInput(serviceManager, function_0, stateFunction, items, minLength, delay, type, value, taAjaxOptions, className, init) {
    if (stateFunction === void 0)
      stateFunction = null;
    if (items === void 0)
      items = 8;
    if (minLength === void 0)
      minLength = 1;
    if (delay === void 0)
      delay = 0;
    if (type === void 0)
      type = InputType.TEXT;
    if (value === void 0)
      value = null;
    if (taAjaxOptions === void 0)
      taAjaxOptions = null;
    if (className === void 0)
      className = null;
    if (init === void 0)
      init = null;
    TypeaheadInput.call(this, null, null, null, items, minLength, delay, type, value, className);
    this.stateFunction_7p3yg8$_0 = stateFunction;
    this.kvUrlPrefix_6kah5n$_0 = window['kv_remote_url_prefix'];
    this.urlPrefix_c4c7g0$_0 = this.kvUrlPrefix_6kah5n$_0 != undefined ? this.kvUrlPrefix_6kah5n$_0.toString() + '/' : '';
    var tmp$ = serviceManager.requireCall_lefff9$(function_0);
    var url = tmp$.component1()
    , method = tmp$.component2();
    var tempAjaxOptions = taAjaxOptions != null ? taAjaxOptions : new TaAjaxOptions();
    this.taAjaxOptions = tempAjaxOptions.copy_e0rzf$(this.urlPrefix_c4c7g0$_0 + drop(url, 1), TypeaheadRemoteInput_init$lambda(this, url), TypeaheadRemoteInput_init$lambda_0, void 0, HttpType$valueOf(method.name));
    init != null ? init(this) : null;
  }
  function TypeaheadRemoteInput_init$lambda(this$TypeaheadRemoteInput, closure$url) {
    return function (query) {
      var tmp$, tmp$_0;
      var squery = JSON.stringify(query);
      var state = (tmp$_0 = (tmp$ = this$TypeaheadRemoteInput.stateFunction_7p3yg8$_0) != null ? tmp$() : null) != null ? JSON.stringify(tmp$_0) : null;
      var $receiver = utils.Serialization.plain;
      var value = new JsonRpcRequest(0, closure$url, listOf([squery, state]));
      var tmp$_1;
      return $receiver.encodeToString_tf03ej$(Kotlin.isType(tmp$_1 = serializer_0($receiver.serializersModule, createKType(getKClass(JsonRpcRequest), [], false)), KSerializer) ? tmp$_1 : throwCCE(), value);
    };
  }
  function TypeaheadRemoteInput_init$lambda_0(it) {
    return copyToArray(utils.Serialization.plain.decodeFromString_awif5v$(ListSerializer(serializer(kotlin_js_internal_StringCompanionObject)), it.result));
  }
  TypeaheadRemoteInput.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'TypeaheadRemoteInput',
    interfaces: [TypeaheadInput]
  };
  function typeaheadRemoteInput($receiver, serviceManager, function_0, stateFunction, items, minLength, delay, type, value, taAjaxOptions, className, init) {
    if (stateFunction === void 0)
      stateFunction = null;
    if (items === void 0)
      items = 8;
    if (minLength === void 0)
      minLength = 1;
    if (delay === void 0)
      delay = 0;
    if (type === void 0)
      type = InputType.TEXT;
    if (value === void 0)
      value = null;
    if (taAjaxOptions === void 0)
      taAjaxOptions = null;
    if (className === void 0)
      className = null;
    if (init === void 0)
      init = null;
    var typeaheadRemoteInput = new TypeaheadRemoteInput(serviceManager, function_0, stateFunction, items, minLength, delay, type, value, taAjaxOptions, className, init);
    $receiver.add_87eobz$(typeaheadRemoteInput);
    return typeaheadRemoteInput;
  }
  var package$io = _.io || (_.io = {});
  var package$kvision = package$io.kvision || (package$io.kvision = {});
  var package$form = package$kvision.form || (package$kvision.form = {});
  var package$text = package$form.text || (package$form.text = {});
  package$text.TypeaheadRemote = TypeaheadRemote;
  package$text.typeaheadRemote_1d8ryr$ = typeaheadRemote;
  $$importsForInline$$['kotlinx-serialization-kotlinx-serialization-core-js-legacy'] = $module$kotlinx_serialization_kotlinx_serialization_core_js_legacy;
  package$text.TypeaheadRemoteInput = TypeaheadRemoteInput;
  package$text.typeaheadRemoteInput_wte0pc$ = typeaheadRemoteInput;
  Kotlin.defineModule('kvision-kvision-bootstrap-typeahead-remote-js-legacy', _);
  return _;
}));
